==> safecheck-3.0.14.jar: filiale/wenxi/sqls/FetchUserFileByOrgChecker.sql <==
SELECT
    *
FROM
    (
        SELECT
            ui.f_userinfo_id,
            ui.f_createfile_date,
            ui.f_userinfo_code,
            ua.f_street,
            ua.f_residential_area,
            ua.f_building,
            ua.f_unit,
            ua.f_floor,
            ua.f_room,
            ua.f_address,
			uf.f_meternumber,
			uf.f_meter_brand,
            ui.f_user_name,
            ui.f_user_phone,
            uf.f_meter_book_num,
            ua.f_slice_area,
            uf.f_user_type,
			ui.f_user_state,
            ua.f_last_check_state,
            ua.f_last_check_result,
            { f_defect_content } AS f_defect_content,
            tp.f_repair_approved_note as f_comments,
            ui.version,
            ui.f_filialeid,
            tp.f_checker_name,
            ua.f_last_check_date
        FROM
            t_userinfo ui
            LEFT JOIN t_user_address ua ON ui.f_userinfo_id= ua.f_userinfo_id
            LEFT JOIN ( SELECT f_user_type,f_meter_book_num,f_userinfo_id,f_meternumber,f_meter_brand FROM t_userfiles tu
            left join t_gasbrand gb on tu.f_gasbrand_id = gb.id WHERE f_table_state = '正常' ) uf ON ua.f_userinfo_id= uf.f_userinfo_id
            LEFT JOIN (
              SELECT
                *
              FROM
                ( SELECT *, ROW_NUMBER () over ( partition BY f_userinfoid ORDER BY f_upload_date  DESC ) AS lastcheck FROM ( SELECT * FROM t_check_paper with (nolock) WHERE { condition.condition2 } ) tp ) t
              WHERE
                lastcheck = 1
	          ) tp ON ui.f_userinfo_id = tp.f_userinfoid
        WHERE
            1 = 1
    ) a
WHERE
    { condition.condition1 }
ORDER BY
    { orderitem}

==> safecheck-3.0.72.jar: filiale/wenxi/sqls/FetchUserFileByOrgChecker.sql <==
SELECT
    *
FROM
    (
        SELECT
            ui.f_userinfo_id,
            ui.f_createfile_date,
            ui.f_userinfo_code,
            ua.f_street,
            ua.f_residential_area,
            ua.f_building,
            ua.f_unit,
            ua.f_floor,
            ua.f_room,
            ua.f_address,
			uf.f_meternumber,
			uf.f_meter_brand,
            ui.f_user_name,
            ui.f_user_phone,
            uf.f_meter_book_num,
            ua.f_slice_area,
            uf.f_user_type,
			ui.f_user_state,
			ui.f_contractdate,
            ua.f_last_check_state,
            ua.f_last_check_result,
            { f_defect_content } AS f_defect_content,
            tp.f_repair_approved_note as f_comments,
            ui.version,
            ui.f_filialeid,
            tp.f_checker_name,
            ua.f_last_check_date,
            uf.f_table_state,
            ua.f_pcd,
            uf.f_position,
            uf.f_metertitles,
            cpl.f_plan_name,
            cpl.f_safecheck_type
        FROM
            t_userinfo ui
            LEFT JOIN t_user_address ua ON ui.f_userinfo_id= ua.f_userinfo_id
            LEFT JOIN ( SELECT f_user_type,f_meter_book_num,f_userinfo_id,f_meternumber,f_meter_brand,f_table_state,f_position,f_metertitles FROM t_userfiles tu
            left join t_gasbrand gb on tu.f_gasbrand_id = gb.id ) uf ON ua.f_userinfo_id= uf.f_userinfo_id and uf.f_table_state != '换表'
            LEFT JOIN (
              SELECT
                *
              FROM
                ( SELECT *, ROW_NUMBER () over ( partition BY f_userinfoid ORDER BY f_upload_date  DESC ) AS lastcheck FROM ( SELECT * FROM t_check_paper with (nolock) WHERE { condition.condition2 } ) tp ) t
              WHERE
                lastcheck = 1
	          ) tp ON ui.f_userinfo_id = tp.f_userinfoid
            LEFT JOIN t_check_plan cpl ON tp.f_check_plan_id= cpl.id
        WHERE
            1 = 1
    ) a
WHERE
    { condition.condition1 }
ORDER BY
    { orderitem}
